==> zend-framework_1.10.3.orig.tar.gz: zend-framework-1.10.3/tests/Zend/Barcode/Object/_files/Ean8_123456_instructions.php <==
<?php
return
array (
  0 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 0,
        1 => 0,
      ),
      1 => 
      array (
        0 => 0,
        1 => 61,
      ),
      2 => 
      array (
        0 => 81,
        1 => 61,
      ),
      3 => 
      array (
        0 => 81,
        1 => 0,
      ),
    ),
    'color' => 16777215,
    'filled' => true,
  ),
  1 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 10,
        1 => 0,
      ),
      1 => 
      array (
        0 => 10,
        1 => 55,
      ),
      2 => 
      array (
        0 => 10,
        1 => 55,
      ),
      3 => 
      array (
        0 => 10,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  2 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 12,
        1 => 0,
      ),
      1 => 
      array (
        0 => 12,
        1 => 55,
      ),
      2 => 
      array (
        0 => 12,
        1 => 55,
      ),
      3 => 
      array (
        0 => 12,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  3 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 16,
        1 => 0,
      ),
      1 => 
      array (
        0 => 16,
        1 => 50,
      ),
      2 => 
      array (
        0 => 16,
        1 => 50,
      ),
      3 => 
      array (
        0 => 16,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  4 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 17,
        1 => 0,
      ),
      1 => 
      array (
        0 => 17,
        1 => 50,
      ),
      2 => 
      array (
        0 => 17,
        1 => 50,
      ),
      3 => 
      array (
        0 => 17,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  5 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 19,
        1 => 0,
      ),
      1 => 
      array (
        0 => 19,
        1 => 50,
      ),
      2 => 
      array (
        0 => 19,
        1 => 50,
      ),
      3 => 
      array (
        0 => 19,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  6 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 22,
        1 => 0,
      ),
      1 => 
      array (
        0 => 22,
        1 => 50,
      ),
      2 => 
      array (
        0 => 22,
        1 => 50,
      ),
      3 => 
      array (
        0 => 22,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  7 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 23,
        1 => 0,
      ),
      1 => 
      array (
        0 => 23,
        1 => 50,
      ),
      2 => 
      array (
        0 => 23,
        1 => 50,
      ),
      3 => 
      array (
        0 => 23,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  8 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 26,
        1 => 0,
      ),
      1 => 
      array (
        0 => 26,
        1 => 50,
      ),
      2 => 
      array (
        0 => 26,
        1 => 50,
      ),
      3 => 
      array (
        0 => 26,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  9 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 29,
        1 => 0,
      ),
      1 => 
      array (
        0 => 29,
        1 => 50,
      ),
      2 => 
      array (
        0 => 29,
        1 => 50,
      ),
      3 => 
      array (
        0 => 29,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  10 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 32,
        1 => 0,
      ),
      1 => 
      array (
        0 => 32,
        1 => 50,
      ),
      2 => 
      array (
        0 => 32,
        1 => 50,
      ),
      3 => 
      array (
        0 => 32,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  11 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 33,
        1 => 0,
      ),
      1 => 
      array (
        0 => 33,
        1 => 50,
      ),
      2 => 
      array (
        0 => 33,
        1 => 50,
      ),
      3 => 
      array (
        0 => 33,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  12 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 35,
        1 => 0,
      ),
      1 => 
      array (
        0 => 35,
        1 => 50,
      ),
      2 => 
      array (
        0 => 35,
        1 => 50,
      ),
      3 => 
      array (
        0 => 35,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  13 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 36,
        1 => 0,
      ),
      1 => 
      array (
        0 => 36,
        1 => 50,
      ),
      2 => 
      array (
        0 => 36,
        1 => 50,
      ),
      3 => 
      array (
        0 => 36,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  14 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 37,
        1 => 0,
      ),
      1 => 
      array (
        0 => 37,
        1 => 50,
      ),
      2 => 
      array (
        0 => 37,
        1 => 50,
      ),
      3 => 
      array (
        0 => 37,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  15 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 38,
        1 => 0,
      ),
      1 => 
      array (
        0 => 38,
        1 => 50,
      ),
      2 => 
      array (
        0 => 38,
        1 => 50,
      ),
      3 => 
      array (
        0 => 38,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  16 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 40,
        1 => 0,
      ),
      1 => 
      array (
        0 => 40,
        1 => 50,
      ),
      2 => 
      array (
        0 => 40,
        1 => 50,
      ),
      3 => 
      array (
        0 => 40,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  17 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 42,
        1 => 0,
      ),
      1 => 
      array (
        0 => 42,
        1 => 55,
      ),
      2 => 
      array (
        0 => 42,
        1 => 55,
      ),
      3 => 
      array (
        0 => 42,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  18 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 44,
        1 => 0,
      ),
      1 => 
      array (
        0 => 44,
        1 => 55,
      ),
      2 => 
      array (
        0 => 44,
        1 => 55,
      ),
      3 => 
      array (
        0 => 44,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  19 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 46,
        1 => 0,
      ),
      1 => 
      array (
        0 => 46,
        1 => 50,
      ),
      2 => 
      array (
        0 => 46,
        1 => 50,
      ),
      3 => 
      array (
        0 => 46,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  20 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 48,
        1 => 0,
      ),
      1 => 
      array (
        0 => 48,
        1 => 50,
      ),
      2 => 
      array (
        0 => 48,
        1 => 50,
      ),
      3 => 
      array (
        0 => 48,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  21 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 49,
        1 => 0,
      ),
      1 => 
      array (
        0 => 49,
        1 => 50,
      ),
      2 => 
      array (
        0 => 49,
        1 => 50,
      ),
      3 => 
      array (
        0 => 49,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  22 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 50,
        1 => 0,
      ),
      1 => 
      array (
        0 => 50,
        1 => 50,
      ),
      2 => 
      array (
        0 => 50,
        1 => 50,
      ),
      3 => 
      array (
        0 => 50,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  23 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 53,
        1 => 0,
      ),
      1 => 
      array (
        0 => 53,
        1 => 50,
      ),
      2 => 
      array (
        0 => 53,
        1 => 50,
      ),
      3 => 
      array (
        0 => 53,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  24 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 56,
        1 => 0,
      ),
      1 => 
      array (
        0 => 56,
        1 => 50,
      ),
      2 => 
      array (
        0 => 56,
        1 => 50,
      ),
      3 => 
      array (
        0 => 56,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  25 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 57,
        1 => 0,
      ),
      1 => 
      array (
        0 => 57,
        1 => 50,
      ),
      2 => 
      array (
        0 => 57,
        1 => 50,
      ),
      3 => 
      array (
        0 => 57,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  26 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 58,
        1 => 0,
      ),
      1 => 
      array (
        0 => 58,
        1 => 50,
      ),
      2 => 
      array (
        0 => 58,
        1 => 50,
      ),
      3 => 
      array (
        0 => 58,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  27 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 60,
        1 => 0,
      ),
      1 => 
      array (
        0 => 60,
        1 => 50,
      ),
      2 => 
      array (
        0 => 60,
        1 => 50,
      ),
      3 => 
      array (
        0 => 60,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  28 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 62,
        1 => 0,
      ),
      1 => 
      array (
        0 => 62,
        1 => 50,
      ),
      2 => 
      array (
        0 => 62,
        1 => 50,
      ),
      3 => 
      array (
        0 => 62,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  29 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 67,
        1 => 0,
      ),
      1 => 
      array (
        0 => 67,
        1 => 50,
      ),
      2 => 
      array (
        0 => 67,
        1 => 50,
      ),
      3 => 
      array (
        0 => 67,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  30 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 70,
        1 => 0,
      ),
      1 => 
      array (
        0 => 70,
        1 => 50,
      ),
      2 => 
      array (
        0 => 70,
        1 => 50,
      ),
      3 => 
      array (
        0 => 70,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  31 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 71,
        1 => 0,
      ),
      1 => 
      array (
        0 => 71,
        1 => 50,
      ),
      2 => 
      array (
        0 => 71,
        1 => 50,
      ),
      3 => 
      array (
        0 => 71,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  32 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 72,
        1 => 0,
      ),
      1 => 
      array (
        0 => 72,
        1 => 50,
      ),
      2 => 
      array (
        0 => 72,
        1 => 50,
      ),
      3 => 
      array (
        0 => 72,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  33 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 74,
        1 => 0,
      ),
      1 => 
      array (
        0 => 74,
        1 => 55,
      ),
      2 => 
      array (
        0 => 74,
        1 => 55,
      ),
      3 => 
      array (
        0 => 74,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  34 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 76,
        1 => 0,
      ),
      1 => 
      array (
        0 => 76,
        1 => 55,
      ),
      2 => 
      array (
        0 => 76,
        1 => 55,
      ),
      3 => 
      array (
        0 => 76,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  35 => 
  array (
    'type' => 'text',
    'text' => '0',
    'size' => 10,
    'position' => 
    array (
      0 => 13,
      1 => 61,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  36 => 
  array (
    'type' => 'text',
    'text' => '1',
    'size' => 10,
    'position' => 
    array (
      0 => 20,
      1 => 61,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  37 => 
  array (
    'type' => 'text',
    'text' => '2',
    'size' => 10,
    'position' => 
    array (
      0 => 27,
      1 => 61,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  38 => 
  array (
    'type' => 'text',
    'text' => '3',
    'size' => 10,
    'position' => 
    array (
      0 => 34,
      1 => 61,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  39 => 
  array (
    'type' => 'text',
    'text' => '4',
    'size' => 10,
    'position' => 
    array (
      0 => 45,
      1 => 61,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  40 => 
  array (
    'type' => 'text',
    'text' => '5',
    'size' => 10,
    'position' => 
    array (
      0 => 52,
      1 => 61,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  41 => 
  array (
    'type' => 'text',
    'text' => '6',
    'size' => 10,
    'position' => 
    array (
      0 => 59,
      1 => 61,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  42 => 
  array (
    'type' => 'text',
    'text' => '5',
    'size' => 10,
    'position' => 
    array (
      0 => 66,
      1 => 61,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
);

==> zend-framework_1.11.11.orig.tar.gz: zend-framework-1.11.11/tests/Zend/Barcode/Object/_files/Ean5_45678_instructions.php <==
<?php
return
array (
  0 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 0,
        1 => 0,
      ),
      1 => 
      array (
        0 => 0,
        1 => 61,
      ),
      2 => 
      array (
        0 => 67,
        1 => 61,
      ),
      3 => 
      array (
        0 => 67,
        1 => 0,
      ),
    ),
    'color' => 16777215,
    'filled' => true,
  ),
  1 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 11,
        1 => 0,
      ),
      1 => 
      array (
        0 => 11,
        1 => 50,
      ),
      2 => 
      array (
        0 => 11,
        1 => 50,
      ),
      3 => 
      array (
        0 => 11,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  2 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 13,
        1 => 0,
      ),
      1 => 
      array (
        0 => 13,
        1 => 50,
      ),
      2 => 
      array (
        0 => 13,
        1 => 50,
      ),
      3 => 
      array (
        0 => 13,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  3 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 14,
        1 => 0,
      ),
      1 => 
      array (
        0 => 14,
        1 => 50,
      ),
      2 => 
      array (
        0 => 14,
        1 => 50,
      ),
      3 => 
      array (
        0 => 14,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  4 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 17,
        1 => 0,
      ),
      1 => 
      array (
        0 => 17,
        1 => 50,
      ),
      2 => 
      array (
        0 => 17,
        1 => 50,
      ),
      3 => 
      array (
        0 => 17,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  5 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 18,
        1 => 0,
      ),
      1 => 
      array (
        0 => 18,
        1 => 50,
      ),
      2 => 
      array (
        0 => 18,
        1 => 50,
      ),
      3 => 
      array (
        0 => 18,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  6 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 19,
        1 => 0,
      ),
      1 => 
      array (
        0 => 19,
        1 => 50,
      ),
      2 => 
      array (
        0 => 19,
        1 => 50,
      ),
      3 => 
      array (
        0 => 19,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  7 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 21,
        1 => 0,
      ),
      1 => 
      array (
        0 => 21,
        1 => 50,
      ),
      2 => 
      array (
        0 => 21,
        1 => 50,
      ),
      3 => 
      array (
        0 => 21,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  8 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 23,
        1 => 0,
      ),
      1 => 
      array (
        0 => 23,
        1 => 50,
      ),
      2 => 
      array (
        0 => 23,
        1 => 50,
      ),
      3 => 
      array (
        0 => 23,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  9 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 25,
        1 => 0,
      ),
      1 => 
      array (
        0 => 25,
        1 => 50,
      ),
      2 => 
      array (
        0 => 25,
        1 => 50,
      ),
      3 => 
      array (
        0 => 25,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  10 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 26,
        1 => 0,
      ),
      1 => 
      array (
        0 => 26,
        1 => 50,
      ),
      2 => 
      array (
        0 => 26,
        1 => 50,
      ),
      3 => 
      array (
        0 => 26,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  11 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 30,
        1 => 0,
      ),
      1 => 
      array (
        0 => 30,
        1 => 50,
      ),
      2 => 
      array (
        0 => 30,
        1 => 50,
      ),
      3 => 
      array (
        0 => 30,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  12 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 32,
        1 => 0,
      ),
      1 => 
      array (
        0 => 32,
        1 => 50,
      ),
      2 => 
      array (
        0 => 32,
        1 => 50,
      ),
      3 => 
      array (
        0 => 32,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  13 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 34,
        1 => 0,
      ),
      1 => 
      array (
        0 => 34,
        1 => 50,
      ),
      2 => 
      array (
        0 => 34,
        1 => 50,
      ),
      3 => 
      array (
        0 => 34,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  14 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 36,
        1 => 0,
      ),
      1 => 
      array (
        0 => 36,
        1 => 50,
      ),
      2 => 
      array (
        0 => 36,
        1 => 50,
      ),
      3 => 
      array (
        0 => 36,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  15 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 37,
        1 => 0,
      ),
      1 => 
      array (
        0 => 37,
        1 => 50,
      ),
      2 => 
      array (
        0 => 37,
        1 => 50,
      ),
      3 => 
      array (
        0 => 37,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  16 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 38,
        1 => 0,
      ),
      1 => 
      array (
        0 => 38,
        1 => 50,
      ),
      2 => 
      array (
        0 => 38,
        1 => 50,
      ),
      3 => 
      array (
        0 => 38,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  17 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 39,
        1 => 0,
      ),
      1 => 
      array (
        0 => 39,
        1 => 50,
      ),
      2 => 
      array (
        0 => 39,
        1 => 50,
      ),
      3 => 
      array (
        0 => 39,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  18 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 41,
        1 => 0,
      ),
      1 => 
      array (
        0 => 41,
        1 => 50,
      ),
      2 => 
      array (
        0 => 41,
        1 => 50,
      ),
      3 => 
      array (
        0 => 41,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  19 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 44,
        1 => 0,
      ),
      1 => 
      array (
        0 => 44,
        1 => 50,
      ),
      2 => 
      array (
        0 => 44,
        1 => 50,
      ),
      3 => 
      array (
        0 => 44,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  20 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 48,
        1 => 0,
      ),
      1 => 
      array (
        0 => 48,
        1 => 50,
      ),
      2 => 
      array (
        0 => 48,
        1 => 50,
      ),
      3 => 
      array (
        0 => 48,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  21 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 50,
        1 => 0,
      ),
      1 => 
      array (
        0 => 50,
        1 => 50,
      ),
      2 => 
      array (
        0 => 50,
        1 => 50,
      ),
      3 => 
      array (
        0 => 50,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  22 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 52,
        1 => 0,
      ),
      1 => 
      array (
        0 => 52,
        1 => 50,
      ),
      2 => 
      array (
        0 => 52,
        1 => 50,
      ),
      3 => 
      array (
        0 => 52,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  23 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 53,
        1 => 0,
      ),
      1 => 
      array (
        0 => 53,
        1 => 50,
      ),
      2 => 
      array (
        0 => 53,
        1 => 50,
      ),
      3 => 
      array (
        0 => 53,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  24 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 55,
        1 => 0,
      ),
      1 => 
      array (
        0 => 55,
        1 => 50,
      ),
      2 => 
      array (
        0 => 55,
        1 => 50,
      ),
      3 => 
      array (
        0 => 55,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  25 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 56,
        1 => 0,
      ),
      1 => 
      array (
        0 => 56,
        1 => 50,
      ),
      2 => 
      array (
        0 => 56,
        1 => 50,
      ),
      3 => 
      array (
        0 => 56,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  26 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 57,
        1 => 0,
      ),
      1 => 
      array (
        0 => 57,
        1 => 50,
      ),
      2 => 
      array (
        0 => 57,
        1 => 50,
      ),
      3 => 
      array (
        0 => 57,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  27 => 
  array (
    'type' => 'text',
    'text' => '45678',
    'size' => 10,
    'position' => 
    array (
      0 => 34,
      1 => 61,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'center',
    'orientation' => 0,
  ),
);
